##  Use To-Dos to Manage Data Collection
When you collect data from multiple experts, it can be difficult to keep track of responsibilities and deadlines. To help you manage this process, SAP LeanIX offers to-dos. These let you assign tasks, set due dates, and monitor progress directly in the platform.
For detailed information about creating and managing to-dos, refer to [To-Dos](https://help.sap.com/docs/leanix/ea/to-dos?locale=en-US&state=PRODUCTION&version=CLOUD "To-dos facilitate task delegation, collaboration, and governance and can be used to ensure data integrity and quality through transparent task management.").
To create a to-do, do the following:
  1. Go to the relevant fact sheet and open the More options (three dots) menu.
  2. Choose Add Action Item (for tasks) or Ask Question (for clarifications).
  3. Enter a Title and optional Description.
  4. Assign the responsible expert and set a Due Date.
  5. Choose Add to save the to-do.


Example of a Cloud Readiness To-Do
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioe7c8b77f4bb44fd1aa6cfcb8330df272_LowRes.png)
